==> haskell-system-fileio-0.3.16.7-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 system-fileio
version:              0.3.16.7
visibility:           public
id:                   system-fileio-0.3.16.7-GHUlK5GHsLu7lEkVVLd2Bn
key:                  system-fileio-0.3.16.7-GHUlK5GHsLu7lEkVVLd2Bn
license:              MIT
maintainer:           https://github.com/fpco/haskell-filesystem
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Consistent filesystem interaction across GHC versions (deprecated package).

category:             System
abi:                  3ac69b3c2c5aab16f57e30282c309619
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-fileio
hs-libraries:         HSsystem-fileio-0.3.16.7-GHUlK5GHsLu7lEkVVLd2Bn
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    system-filepath-0.4.14.1-1GUCo9qAB7EGc1EwM0vkpa text-2.0.2
    time-1.12.2 unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-fileio-0.3.16.7-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 system-fileio
version:              0.3.16.7
visibility:           public
id:                   system-fileio-0.3.16.7-DI7mqureix8CUweITa2W0E
key:                  system-fileio-0.3.16.7-DI7mqureix8CUweITa2W0E
license:              MIT
maintainer:           https://github.com/fpco/haskell-filesystem
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Consistent filesystem interaction across GHC versions (deprecated package).

category:             System
abi:                  53d68f3971f03aeb86a23d6165df7533
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-fileio
hs-libraries:         HSsystem-fileio-0.3.16.7-DI7mqureix8CUweITa2W0E
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    system-filepath-0.4.14.1-3ZpOu78UG8XJidPodeZtYP text-2.0.2
    time-1.12.2 unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
